<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
//use Elementor\Repeater;
//use Elementor\Group_Control_Image_Size;
//use Elementor\Group_Control_Css_Filter;
//defined( 'ABSPATH' ) || exit;

class Classiera_Widget_Ads_styles extends \Elementor\Widget_Base {
	public function get_name() {
		return 'classiera-adv-styles';
	}
	public function get_title() {
		return esc_html__( 'Classiera Advertisement', 'classiera-elementor' );
	}
	public function get_icon() {
		return 'eicon-posts-grid';
	}
	public function get_categories() {
		return [ 'classiera' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'classiera-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);		
		$this->add_control( 'layout_style', [
			'label'   => esc_html__( 'Ads style', 'classiera-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				's1'=> esc_html__( 'Style 1', 'classiera-elementor' ),
				's2'=> esc_html__( 'Style 2', 'classiera-elementor' ),
				's3'=> esc_html__( 'Style 3', 'classiera-elementor' ),
				's4'=> esc_html__( 'Style 4', 'classiera-elementor' ),
				's5'=> esc_html__( 'Style 5', 'classiera-elementor' ),
				's6'=> esc_html__( 'Style 6', 'classiera-elementor' ),
				's7'=> esc_html__( 'Style 7', 'classiera-elementor' ),
			],
			'default' => 's1',
		] );
		$this->add_control( 'orderby', [
			'label'   => esc_html__( 'Regular ads orderby', 'classiera-elementor' ),
			'description'   => esc_html__( 'Select post order only regular ads', 'classiera-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'title'=> esc_html__( 'Title', 'classiera-elementor' ),
				'name'=> esc_html__( 'Name', 'classiera-elementor' ),
				'date'=> esc_html__( 'Date', 'classiera-elementor' ),
				'rand'=> esc_html__( 'Random', 'classiera-elementor' ),
			],
			'default' => 'date',
		] );
		$this->add_control( 'orderbyf', [
			'label'   => esc_html__( 'Featured ads orderby', 'classiera-elementor' ),
			'description'   => esc_html__( 'Select post order only featured ads', 'classiera-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'title'=> esc_html__( 'Title', 'classiera-elementor' ),
				'name'=> esc_html__( 'Name', 'classiera-elementor' ),
				'date'=> esc_html__( 'Date', 'classiera-elementor' ),
				'rand'=> esc_html__( 'Random', 'classiera-elementor' ),
			],
			'default' => 'rand',
		] );
		$this->add_control(
            'nop',
            [
                'label' => __( 'Ads Count', 'classiera-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'classiera-elementor' ),
                'description' => __( 'How many regular ads you want to show in this section?', 'classiera-elementor' ),
            ]
        );
		$this->add_control(
            'nofp',
            [
                'label' => __( 'Featured Ads Count', 'classiera-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'description' => __( 'How many featured ads you want to show before regular ads?', 'classiera-elementor' ),
                'placeholder' => __( 'Enter a number', 'classiera-elementor' ),
            ]
        );
		$this->add_control(
            'show_tab_btn',
            [
                'label' => __( 'Grid/List buttons', 'classiera-elementor' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'classiera-elementor' ),
                'label_off' => __( 'Hide', 'classiera-elementor' ),
                'description' => __( 'Hide/Show Grid List Change view button on front-end.', 'classiera-elementor' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
		$this->end_controls_section();
	}	
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(			
			'layout' => $settings['layout_style'],
			'orderby' => $settings['orderby'],
			'orderbyf' => $settings['orderbyf'],
			'number_of_post' => $settings['nop'],
			'number_of_fpost' => $settings['nofp'],
			'show_tab_btn' => $settings['show_tab_btn'],
		);
		/***********************
		Get Theme Options
		**********************/
		global $redux_demo;
		$classiera_ads_typeOn = false;
		$classieraAdsView = 'grid';		
		if( class_exists( 'Redux' )) {   
		   $redux_demo = get_option( 'redux_demo' );
		}
		$classieraAdsView = $redux_demo['home-ads-view'];
		$classiera_ads_typeOn = $redux_demo['classiera_ads_type'];
		if($classiera_ads_typeOn == 1){
			$adstypeQuery = array(
				'key' => 'classiera_ads_type',
				'value' => 'sold',
				'compare' => '!='
			);
		}else{
			$adstypeQuery = null;
		}
		/***********************
		convert to vars
		**********************/		
		$postStyle = $settings['layout_style'];
		$orderby = $settings['orderby'];
		$orderbyf = $settings['orderbyf'];
		$count = $settings['nop'];
		$fcount = $settings['nofp'];
		$showTabBTN = $settings['show_tab_btn'];
		$paged = (get_query_var('paged')) ? get_query_var('paged') : ((get_query_var('page')) ? get_query_var('page') : 1);
		$fargs = array(
			'post_type' => 'post',
			'post_status' => 'publish',
			'orderby' => $orderbyf,
			'posts_per_page' => $fcount,
			'paged' => $paged,
			'meta_query' => array(
				array(
					'key' => 'featured_post',
					'value' => '1',
					'compare' => '=='
				),
				$adstypeQuery,
			),
		);
		$featured_query = new WP_Query($fargs);
		$featuredIDS = array();
		$featuredIDS = wp_list_pluck( $featured_query->posts, 'ID' );
		$args = array(
			'post_type' => 'post',
			'orderby' => $orderby,
			'posts_per_page' => (int) $count,
			'paged' => $paged,
			'post__not_in' => $featuredIDS,
			'meta_query' => array(
				$adstypeQuery,
			),
		);
		$wp_query = new WP_Query($args);
		if ($wp_query->have_posts()){
			switch ($postStyle) {
				case 's1':
				?>
				<section class="classiera-advertisement advertisement-v1">
					<div class="tab-divs section-light-bg">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-sm-6 col-xs-6">
										<div class="total-post">
											<?php 
												$classieraPostCount = wp_count_posts();
												$classieraPublishPCount = $classieraPostCount->publish;
											?>
											<p><?php esc_html_e( 'Total ads', 'classiera-elementor' ); ?>: 
												<span>
												<?php echo esc_attr($classieraPublishPCount); ?> 
												<?php esc_html_e( 'ads posted', 'classiera-elementor' ); ?>
												</span>
											</p>
										</div><!--total-post-->
									</div><!--col-lg-6-->
									<div class="col-lg-6 col-sm-6 col-xs-6">
									<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as text-right flip">
											<span><?php esc_html_e( 'View as', 'classiera-elementor' ); ?>:</span>
											<a id="grid" class="grid btn btn-sm sharp outline <?php if($classieraAdsView == 'grid'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-large"></i>
											</a>
											<a id="grid-medium" class="grid-medium btn btn-sm sharp outline <?php if($classieraAdsView == 'medium'){ echo "active"; }?>" href="#">
												<i class="fa fa-th"></i>
											</a>
											<a id="list" class="list btn btn-sm sharp <?php if($classieraAdsView == 'list'){ echo "active"; }?>" href="#">
												<i class="fas fa-bars"></i>
											</a>
										</div><!--view-as-->
									<?php }else{ ?>
									&nbsp;
									<?php } ?>
									</div><!--col-lg-6-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row">
									<?php
									while ($featured_query->have_posts()) : $featured_query->the_post();
									get_template_part( 'templates/classiera-loops/loop-lime');
									endwhile;
									wp_reset_query($featured_query);
									while ($wp_query->have_posts()) : $wp_query->the_post();
									get_template_part( 'templates/classiera-loops/loop-lime');
									endwhile;
									?>
									</div><!--row-->
								</div><!--container-->
							</div><!--tab-pane-->
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;	
				case 's2':
				?>
				<section class="classiera-advertisement advertisement-v2 section-pad-top-100">
					<div class="tab-divs">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-sm-8">
									&nbsp;
									</div><!--col-lg-6 col-sm-8-->
									<div class="col-lg-6 col-sm-4">
									<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as text-right flip">
											<span><?php esc_html_e( 'View as', 'classiera-elementor' ); ?>:</span>
											<div class="btn-group">
												<a id="grid" class="grid btn btn-primary radius btn-md <?php if($classieraAdsView == 'grid'){ echo "active"; }?>" href="#">
													<i class="fas fa-th-large"></i>
												</a>
												<a id="grid-medium" class="grid-medium btn btn-primary radius btn-md <?php if($classieraAdsView == 'medium'){ echo "active"; }?>" href="#">
													<i class="fa fa-th"></i>
												</a>
												<a id="list" class="list btn btn-primary btn-md radius <?php if($classieraAdsView == 'list'){ echo "active"; }?>" href="#">
													<i class="fas fa-th-list"></i>
												</a>
											</div>
										</div>
										<?php }else{ ?>
										&nbsp;
										<?php } ?>
									</div><!--col-lg-6 col-sm-4-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content section-gray-bg">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row">
										<?php
										while ($featured_query->have_posts()) : $featured_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-strobe');
										endwhile;
										wp_reset_query($featured_query);
										while ($wp_query->have_posts()) : $wp_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-strobe');
										endwhile;
										?>
									</div><!--row-->
								</div><!--container-->
							</div><!--tab-pane-->
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;
				case 's3':
				?>
				<section class="classiera-advertisement advertisement-v3 section-pad-top-100">
					<div class="tab-divs">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-sm-8">
										&nbsp;
									</div><!--col-lg-6 col-sm-8-->
									<div class="col-lg-6 col-sm-4">
										<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as text-right flip">
											<span><?php esc_html_e( 'View as', 'classiera-elementor' ); ?>:</span>
											<div class="btn-group">
												<a id="grid" class="grid <?php if($classieraAdsView == 'grid'){ echo "active"; }?>" href="#">
													<i class="fas fa-th-large"></i>
												</a>
												<a id="grid" class="grid-medium <?php if($classieraAdsView == 'medium'){ echo "active"; }?>" href="#">
													<i class="fa fa-th"></i>
												</a>
												<a id="list" class="list <?php if($classieraAdsView == 'list'){ echo "active"; }?>" href="#">
													<i class="fas fa-th-list"></i>
												</a>
											</div>
										</div>
										<?php }else{ ?>
										&nbsp;
										<?php } ?>
									</div><!--col-lg-6 col-sm-4-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content section-gray-bg">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row">
										<?php
										while ($featured_query->have_posts()) : $featured_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-coral');
										endwhile;
										wp_reset_query($featured_query);
										while ($wp_query->have_posts()) : $wp_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-coral');
										endwhile;
										?>
									</div><!--row-->
								</div><!--container-->
							</div><!--tab-pane-->
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;
				case 's4':
				?>
				<section class="classiera-advertisement advertisement-v4 section-pad-top-100">
					<div class="tab-divs">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-sm-8 col-xs-12">
										&nbsp;
									</div><!--col-lg-6 col-sm-8-->
									<div class="col-lg-6 col-sm-4 col-xs-12">
									<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as tab-button">
											<ul class="nav nav-tabs pull-right flip" role="tablist">
												<li><span><?php esc_html_e( 'View as', 'classiera-elementor' ); ?></span></li>
												<li role="presentation" class="<?php if($classieraAdsView == 'grid' || $classieraAdsView == 'medium'){ echo "active"; }?>">
													<a id="grid" class="masonry" href="#">
														<i class="zmdi zmdi-view-dashboard"></i>
														<span class="arrow-down"></span>
													</a>
												</li>
												<li role="presentation" class="<?php if($classieraAdsView == 'list'){ echo "active"; }?>">
													<a id="list" class="list" href="#">
														<i class="zmdi zmdi-view-list"></i>
														<span class="arrow-down"></span>
													</a>
												</li>
											</ul>
										</div><!--view-as tab-button-->
										<?php }else{ ?>
										&nbsp;
										<?php } ?>
									</div><!--col-lg-6 col-sm-4 col-xs-12-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content section-gray-bg">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row masonry-content">
										<?php
										while ($featured_query->have_posts()) : $featured_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-canary');
										endwhile;
										wp_reset_query($featured_query);
										while ($wp_query->have_posts()) : $wp_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-canary');
										endwhile;
										?>
									</div>
								</div><!--container-->
							</div><!--tab-pane-->
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;
				case 's5':
				?>
				<section class="classiera-advertisement advertisement-v5 section-pad-80 border-bottom">
					<div class="tab-divs">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-sm-7 col-xs-8">
										&nbsp;
									</div><!--col-lg-6 col-sm-8-->
									<div class="col-lg-6 col-sm-5 col-xs-4">
									<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as text-right flip">
											<a id="grid" class="grid <?php if($classieraAdsView == 'grid'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-large"></i>
											</a>
											<a id="grid" class="grid-medium <?php if($classieraAdsView == 'medium'){ echo "active"; }?>" href="#">
												<i class="fa fa-th"></i>
											</a>
											<a id="list" class="list <?php if($classieraAdsView == 'list'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-list"></i>
											</a>							
										</div><!--view-as tab-button-->
										<?php }else{ ?>
										&nbsp;
										<?php } ?>
									</div><!--col-lg-6 col-sm-4 col-xs-12-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row">
										<?php
										while ($featured_query->have_posts()) : $featured_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-ivy');
										endwhile;
										wp_reset_query($featured_query);
										while ($wp_query->have_posts()) : $wp_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-ivy');
										endwhile;
										?>
									</div>
								</div>
							</div><!--tab-pane-->
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;
				case 's6':
				?>
				<section class="classiera-advertisement advertisement-v6 section-pad border-bottom">
					<div class="tab-divs">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-8 col-sm-8">
										&nbsp;
									</div><!--col-lg-8 col-sm-8-->
									<div class="col-lg-4 col-sm-4">
									<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as text-right flip">
											<a id="grid" class="grid <?php if($classieraAdsView == 'grid'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-large"></i>
											</a>
											<a id="grid" class="grid-medium <?php if($classieraAdsView == 'medium'){ echo "active"; }?>" href="#">
												<i class="fa fa-th"></i>
											</a>
											<a id="list" class="list <?php if($classieraAdsView == 'list'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-list"></i>
											</a>							
										</div><!--view-as tab-button-->
										<?php }else{ ?>
										&nbsp;
										<?php } ?>
									</div><!--col-lg-4 col-sm-4 col-xs-12-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row">
										<?php
										while ($featured_query->have_posts()) : $featured_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-iris');
										endwhile;
										wp_reset_query($featured_query);
										while ($wp_query->have_posts()) : $wp_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-iris');
										endwhile;
										?>
									</div><!--row-->
								</div><!--container-->
							</div><!--tab-pane-->
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;
				case 's7':
				?>
				<section class="classiera-advertisement advertisement-v6 advertisement-v7 section-pad border-bottom">
					<div class="tab-divs">
						<div class="view-head">
							<div class="container">
								<div class="row">
									<div class="col-lg-6 col-sm-8">
										&nbsp;
									</div><!--col-lg-6 col-sm-8-->
									<div class="col-lg-6 col-sm-4">
									<?php if('yes' === $showTabBTN){ ?>
										<div class="view-as text-right flip">
											<a id="grid" class="grid <?php if($classieraAdsView == 'grid'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-large"></i>
											</a>
											<a id="grid" class="grid-medium <?php if($classieraAdsView == 'medium'){ echo "active"; }?>" href="#">
												<i class="fa fa-th"></i>
											</a>
											<a id="list" class="list <?php if($classieraAdsView == 'list'){ echo "active"; }?>" href="#">
												<i class="fas fa-th-list"></i>
											</a>							
										</div><!--view-as tab-button-->
										<?php }else{ ?>
										&nbsp;
										<?php } ?>
									</div><!--col-lg-6 col-sm-4 col-xs-12-->
								</div><!--row-->
							</div><!--container-->
						</div><!--view-head-->
						<div class="tab-content">
							<div role="tabpanel" class="tab-pane fade in active" id="all">
								<div class="container">
									<div class="row">
										<?php
										while ($featured_query->have_posts()) : $featured_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-allure');
										endwhile;
										wp_reset_query($featured_query);
										while ($wp_query->have_posts()) : $wp_query->the_post();
										get_template_part( 'templates/classiera-loops/loop-allure');
										endwhile;
										?>
									</div><!--row-->
								</div><!--container-->
							</div>
						</div><!--tab-content-->
					</div><!--tab-divs-->
				</section>
				<?php					
				break;
			}			
		}		
	}
}