<?php
use Elementor\Plugin;
use Elementor\Controls_Manager;
class Classiera_blogs_styles extends \Elementor\Widget_Base {
	public function get_name() {
		return 'classiera-blogs-styles';
	}
	public function get_title() {
		return esc_html__( 'Classiera Blogs', 'classiera-elementor' );
	}
	public function get_icon() {
		return 'eicon-posts-ticker';
	}
	public function get_categories() {
		return [ 'classiera' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'setting_section',
			[
				'label' => __( 'Setting', 'classiera-elementor' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control( 'layout_style', [
			'label'   => esc_html__( 'Blogs style', 'classiera-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				's1'=> esc_html__( 'Style 1', 'classiera-elementor' ),
				's2'=> esc_html__( 'Style 2', 'classiera-elementor' ),
				's3'=> esc_html__( 'Style 3', 'classiera-elementor' ),
				's4'=> esc_html__( 'Style 4', 'classiera-elementor' ),
			],
			'default' => 's1',
		] );
		$this->add_control( 'orderby', [
			'label'   => esc_html__( 'Order by', 'classiera-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'title'=> esc_html__( 'Order by title', 'classiera-elementor' ),
				'name'=> esc_html__( 'Order by name', 'classiera-elementor' ),
				'date'=> esc_html__( 'Order by date', 'classiera-elementor' ),
				'rand'=> esc_html__( 'Order by random', 'classiera-elementor' ),
			],
			'default' => 'rand',
		] );
		$this->add_control( 'order', [
			'label'   => esc_html__( 'Order', 'classiera-elementor' ),
			'type' => Controls_Manager::SELECT2,
			'options' => [
				'ASC'=> esc_html__( 'Order by ASC', 'classiera-elementor' ),
				'DESC'=> esc_html__( 'Order by DESC', 'classiera-elementor' ),
			],
			'default' => 'ASC',
		] );
		$this->add_control(
            'nop',
            [
                'label' => __( 'Number of posts', 'classiera-elementor' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => __( 'Enter a number', 'classiera-elementor' ),
				'default' => '5',
            ]			
        );
		$this->end_controls_section();
	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$atts = array(			
			'layout' => $settings['layout_style'],		
			'orderby' => $settings['orderby'],		
			'order' => $settings['order'],		
			'nop' => $settings['nop'],		
		);
		/***********************
		convert to vars
		**********************/	
		$blogStyle = $settings['layout_style'];
		$orderby = $settings['orderby'];
		$order = $settings['order'];
		$nop = $settings['nop'];
		$args = array (
			'post_type' => array('blog','blog_posts'),
			'post_status' => 'publish',
			'posts_per_page' => $nop,
			'order' => $order,
			'orderby' => $orderby,
		);
		$blogSecQuery = new WP_Query($args);
		if ( $blogSecQuery->have_posts() ){
			switch ($blogStyle) {
				case 's1':
					$sectionClass = 'blog-post-section section-pad';
					$divClass = 'blog-post match-height';
				break;
				case 's2':
					$sectionClass = 'blog-post-section blog-post-section-bg section-pad-80 border-bottom';
					$divClass = 'blog-post blog-post-v2 match-height';
				break;
				case 's3':
					$sectionClass = 'blog-post-section section-pad border-bottom';
					$divClass = 'blog-post blog-post-v2 blog-post-v3 match-height';
				break;
				case 's4':
					$sectionClass = 'blog-post-section section-pad border-bottom';
					$divClass = 'blog-post blog-post-v2 blog-post-v4 match-height';
				break;
			}
			?>
			<section class="<?php echo esc_attr($sectionClass); ?>">
				<div class="container">
					<div class="row">
					<?php
					while ( $blogSecQuery->have_posts() ) : $blogSecQuery->the_post();
					$user_ID = $post->post_author;
					$classieradateFormat = get_option( 'date_format' );
					?>
					<div class="col-lg-4 col-sm-6 col-md-4">
						<div class="<?php echo esc_attr($divClass); ?>">
							<div class="blog-post-img-sec">
								<div class="blog-img">
									<?php 
									if( has_post_thumbnail()){
										echo get_the_post_thumbnail();
									}	
									?>	
									<span class="hover-posts">
										<a href="<?php the_permalink(); ?>" class="btn btn-primary radius btn-md active">
											<?php esc_html_e( 'View Post', 'classiera-elementor' ); ?>
										</a>
									</span>
								</div>
							</div>
							<div class="blog-post-content">
								<h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
								<p>
									<span>
										<i class="fas fa-user"></i>
										<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>"><?php echo get_the_author_meta('display_name', $user_ID ); ?></a>
									</span>
									<span class="classiera_pdate"><i class="far fa-clock"></i><?php echo get_the_date($classieradateFormat, $post->ID); ?></span>
									<span><i class="fas fa-comments"></i>
										<?php printf( _nx( 'One Comment', '%1$s Comments', get_comments_number(), 'comments title', 'classiera-elementor' ), number_format_i18n( get_comments_number() ) );?>
									</span>
								</p>
							</div>
						</div>
					</div>
					<?php endwhile; ?>	
					</div><!--row-->
				</div><!--container-->
			</section>
		<?php
		}wp_reset_query();
	}
}