<?php
class classiera_post_by_locations extends WP_Widget{
	public function __construct() {		
        $widget_ops = array(
			'classname' => 'recent_post_by_location',
			'description' => 'Classiera recent posts by location.'
		);        
		parent::__construct( 'classiera_recent_postby_location', esc_html__( 'Classiera recent posts by location', 'classiera-helper' ), $widget_ops );
    }
	/*==========================
	Outputs the content of the widget
	@param array $args
	@param array $instance
	===========================*/
	function widget($args, $instance) {
		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}		
		$widget_style = $instance['widget_style'];
		/*==========================
		Setup Posts data
		===========================*/
		$classierargs = array(
			'post_type' => 'post',
			'post_status' => 'publish',
			'posts_per_page' => $instance['number_posts'],
			'meta_query' => array(
				'relation' => 'AND',
				array(
					'key'     => 'post_location',
					'value'   => $instance['post_location'],
					'compare'   => 'LIKE',
				),
			)
		);
		$widgetPosts = get_posts($classierargs);		
		$classieraThumSrc = "";
		$thumb_id = "";
		$classieraALT = "";
		echo '<div class="widget-content">';
		if($widgetPosts){
			foreach ( $widgetPosts as $post ){
				setup_postdata( $post );
				?>
				<div class="media footer-pr-widget-<?php echo esc_attr($widget_style); ?>">
					<div class="media-left">
						<a class="media-img" href="<?php echo esc_url(get_permalink($post->ID)); ?>">
							<?php 
							if ( has_post_thumbnail($post->ID)){
							$classieraThumSrc = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'classiera-100');
							$thumb_id = get_post_thumbnail_id($post->ID);
							$classieraALT = get_post_meta($thumb_id, '_wp_attachment_image_alt', true);
							?>
							<img class="media-object" src="<?php echo esc_url($classieraThumSrc[0]); ?>" alt="<?php echo get_the_title($post->ID);?>">
							<?php }else{
								$classieraDEFThumb = get_template_directory_uri() . '/images/nothumb.png'
							?>
							<img class="media-object" src="<?php echo esc_url($classieraDEFThumb); ?>" alt="<?php echo get_the_title($post->ID);?>">	
								<?php
							}?>
						</a>
					</div>
					<div class="media-body">
						<?php if($widget_style == 'v1'){?>
						<?php
						$post_currency_tag = get_post_meta($post->ID, 'post_currency_tag', true);
						?>
						<?php $classieraPostPrice = get_post_meta($post->ID, 'post_price', true); ?>
						<?php if($classieraPostPrice){ ?>
						<span class="price">
							<?php 
							if(is_numeric($classieraPostPrice)){
								echo classiera_post_price_display($post_currency_tag, $classieraPostPrice);
							}else{ 
								echo esc_html($classieraPostPrice); 
							}
							?>
						</span>
						<?php } ?>
						<h4 class="media-heading">
							<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_title($post->ID);?></a>
						</h4>
						<?php 
							$categories = get_the_category($post->ID);
							if (! empty( $categories )){
								$classieraCategory =  esc_html( $categories[0]->name );   
								$classieraCategoryURL = esc_url(get_category_link($categories[0]->term_id ));   
							}
						?>
						<span class="category">
							<?php esc_html_e( 'Category', 'classiera-helper'); ?>: 
							<a href="<?php echo esc_url($classieraCategoryURL); ?>"><?php echo esc_html($classieraCategory); ?></a>
						</span>
						<?php }elseif($widget_style == 'v2'){?>
							<?php $classieradateFormat = get_option( 'date_format' );?>
							<span><i class="far fa-clock"></i><?php echo get_the_date($classieradateFormat, $post->ID); ?></span>
							<h5 class="media-heading">
								<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_title($post->ID);?></a>
							</h5>
							<?php 
							$post_currency_tag = get_post_meta($post->ID, 'post_currency_tag', true);
							?>
							<?php $classieraPostPrice = get_post_meta($post->ID, 'post_price', true); ?>
							<?php if($classieraPostPrice){ ?>
							<p class="price"><?php esc_html_e( 'Price', 'classiera-helper'); ?> : <span class="color">
								<?php 
								if(is_numeric($classieraPostPrice)){
									echo classiera_post_price_display($post_currency_tag, $classieraPostPrice);
								}else{ 
									echo esc_html($classieraPostPrice); 
								}
								?>
							</span></p>
							<?php } ?>
							<?php 
							$categories = get_the_category($post->ID);
								if (! empty( $categories )){
									$classieraCategory =  esc_html( $categories[0]->name );   
									$classieraCategoryURL = esc_url(get_category_link($categories[0]->term_id ));   
								}								
							?>
							<span class="category">
								<?php esc_html_e( 'Category', 'classiera-helper'); ?>: 
								<a href="<?php echo esc_url($classieraCategoryURL); ?>"><?php echo esc_html($classieraCategory); ?></a>
							</span>
							<span class="category">
							<?php
							$author_ID = $post->post_author;
							$authorName = get_the_author_meta('display_name', $author_ID );
							if(empty($authorName)){
								$authorName = get_the_author_meta('user_nicename', $author_ID );
							}
							if(empty($authorName)){
								$authorName = get_the_author_meta('user_login', $author_ID );
							}
							?>
								<?php esc_html_e( 'Author', 'classiera-helper'); ?>: 
								<a href="<?php echo get_author_posts_url($author_ID); ?>"><?php echo esc_attr($authorName); ?></a>
							</span>
							
						<?php } ?>
					</div>
				</div>
				<?php
			}wp_reset_postdata();
		}
		echo '</div>';		
		echo $args['after_widget'];
	}
	/*==========================
	Outputs the options form on admin
	@param array $instance The widget options
	===========================*/
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'Classiera recent posts', 'classiera-helper' );
		$number_posts = ! empty( $instance['number_posts'] ) ? $instance['number_posts'] : 3;
		$post_location = ! empty( $instance['post_location'] ) ? $instance['post_location'] : '';
		$widget_style = ! empty( $instance['widget_style'] ) ? $instance['widget_style'] : 'v1';
		?>
		<!--Title Field-->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
				<?php esc_attr_e( 'Title:', 'classiera-helper' ); ?>
			</label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>		
		<!--Select Country-->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'post_location' ) ); ?>">
				<?php esc_attr_e( 'Posts styles', 'classiera-helper' ); ?>
			</label>
			<select class="widefat" id="<?php echo esc_attr($this->get_field_id('post_location')); ?>" name="<?php echo esc_attr($this->get_field_name('post_location')); ?>">
				<?php
				$locargs = array(
					'post_type' => 'countries',
					'posts_per_page'   => -1,
					'orderby'          => 'title',
					'order'            => 'ASC',
					'post_status'      => 'publish',
					'suppress_filters' => false 
				);
				$country_posts = get_posts($locargs);
				?>
                <option value="-1" selected disabled>
					<?php esc_html_e('Select Country', 'classiera-helper'); ?>
				</option>
                <?php if(!empty($country_posts)){
					foreach( $country_posts as $country_post ){ ?>
					<option value="<?php echo esc_html( $country_post->post_title ); ?>" <?php selected( $country_post->post_title, $post_location ); ?>>
						<?php echo esc_html( $country_post->post_title ); ?>
					</option>
					<?php }
				}?>
            </select>
		</p>
		<!--Widget style-->
		<p>
            <label for="<?php echo esc_attr($this->get_field_id('widget_style')); ?>"><?php esc_html_e('Widget Style', 'classiera-helper');?>:</label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('widget_style')); ?>" name="<?php echo esc_attr($this->get_field_name('widget_style')); ?>">
                <option value="v1" <?php if ($widget_style == 'v1') print 'selected="selected"'; ?>><?php esc_html_e('Style 1', 'classiera-helper');?></option>
                <option value="v2" <?php if ($widget_style == 'v2') print 'selected="selected"'; ?>><?php esc_html_e('Style 2', 'classiera-helper');?></option>
            </select>
        </p>
		<!--Post Count-->
		<p>
            <label for="<?php echo esc_attr($this->get_field_id('number_posts')); ?>">
				<?php esc_html_e('Number of posts to show', 'classiera-helper');?>:
			</label>
            <input  id="<?php echo esc_attr($this->get_field_id('number_posts')); ?>" name="<?php echo esc_attr($this->get_field_name('number_posts')); ?>" value="<?php echo esc_attr($number_posts); ?>" size="3"  />
        </p>
		<?php
	}
	/*==========================
	Processing widget options on save
	@param array $new_instance The new options
	@param array $old_instance The previous options
	@return array
	===========================*/
	function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';		
		$instance['post_location'] = ( ! empty( $new_instance['post_location'] ) ) ? sanitize_text_field( $new_instance['post_location'] ) : '';
		$instance['number_posts'] = ( ! empty( $new_instance['number_posts'] ) ) ? sanitize_text_field( $new_instance['number_posts'] ) : '';
		$instance['widget_style'] = ( ! empty( $new_instance['widget_style'] ) ) ? sanitize_text_field( $new_instance['widget_style'] ) : '';
		return $instance;
	}
}
/*==========================
Register Recent post widget
using widgets_init hook
===========================*/
add_action( 'widgets_init', function(){
	register_widget( 'classiera_post_by_locations' );
});